@@ -817,11 +817,11 @@ static void wp_tdmv_report_alarms(void* pcard, unsigned long te_alarm)
 				card->wandev.fe_iface.set_fe_lbmode(
 						&wp->card->fe,
 					       	WAN_TE1_DDLB_MODE,
-					       	WAN_TE1_LB_DISABLE);
+					       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
 				card->wandev.fe_iface.set_fe_lbmode(
 						&wp->card->fe,
 						WAN_TE1_LINELB_MODE,
-					       	WAN_TE1_LB_ENABLE);
+					       	WAN_TE1_LB_ENABLE,ENABLE_ALL_CHANNELS);
 				wp->span.maintstat = ZT_MAINT_REMOTELOOP;
 			}
 		}else{
@@ -834,11 +834,11 @@ static void wp_tdmv_report_alarms(void* pcard, unsigned long te_alarm)
 				card->wandev.fe_iface.set_fe_lbmode(
 						&wp->card->fe,
 						WAN_TE1_DDLB_MODE,
-					       	WAN_TE1_LB_DISABLE);
+					       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
 				card->wandev.fe_iface.set_fe_lbmode(
 						&wp->card->fe,
 						WAN_TE1_LINELB_MODE,
-					       	WAN_TE1_LB_DISABLE);
+					       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
 				wp->span.maintstat = ZT_MAINT_NONE;
 			}
 		}else{
@@ -1357,11 +1357,11 @@ static int wp_tdmv_maint(struct zt_span *span, int cmd)
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_DDLB_MODE,
-				       	WAN_TE1_LB_DISABLE);
+				       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_LINELB_MODE,
-				       	WAN_TE1_LB_DISABLE);
+				       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
 			break;
 	    	case ZT_MAINT_LOCALLOOP:
 			DEBUG_EVENT("%s: T1: Set to local loopback mode (local/no remote loop)\n",
@@ -1369,11 +1369,11 @@ static int wp_tdmv_maint(struct zt_span *span, int cmd)
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_LINELB_MODE,
-				       	WAN_TE1_LB_DISABLE);
+				       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_DDLB_MODE,
-				       	WAN_TE1_LB_ENABLE);
+				       	WAN_TE1_LB_ENABLE,ENABLE_ALL_CHANNELS);
 			break;
 	    	case ZT_MAINT_REMOTELOOP:
 			DEBUG_EVENT("%s: T1: Set to remote loopback mode (no local/remote loop)\n",
@@ -1381,11 +1381,11 @@ static int wp_tdmv_maint(struct zt_span *span, int cmd)
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_LINELB_MODE,
-				       	WAN_TE1_LB_ENABLE);
+				       	WAN_TE1_LB_ENABLE,ENABLE_ALL_CHANNELS);
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_LINELB_MODE,
-				       	WAN_TE1_LB_DISABLE);
+				       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
 			break;
 	    	case ZT_MAINT_LOOPUP:
 			DEBUG_EVENT("%s: T1: Send loopup code\n",
@@ -1393,7 +1393,7 @@ static int wp_tdmv_maint(struct zt_span *span, int cmd)
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_TX_LINELB_MODE,
-				       	WAN_TE1_LB_ENABLE);
+				       	WAN_TE1_LB_ENABLE,ENABLE_ALL_CHANNELS);
 			break;
 	    	case ZT_MAINT_LOOPDOWN:
 			DEBUG_EVENT("%s: T1: Send loopdown code\n",
@@ -1401,7 +1401,7 @@ static int wp_tdmv_maint(struct zt_span *span, int cmd)
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_TX_LINELB_MODE,
-				       	WAN_TE1_LB_DISABLE);
+				       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
 			break;
 	    	case ZT_MAINT_LOOPSTOP:
 			DEBUG_EVENT("%s: T1: Stop sending loop code\n",
